<input id="{{ widget.attrs.id }}" type="{{ widget.type }}" name="{{ widget.name }}" value="{{ widget.value }}" maxlength="{{ widget.attr.maxlength }}" required="{{ widget.attr.required }}" class="show_similar_input">
<div data-label="{{ label }}" data-model="{{ target_model }}" data-id="{{ instance_id }}" data-threshold="{{ threshold }}" data-max_items="{{ max_items }}">
</div>
